pub struct FixedTime {
pub period: Duration,
/* private fields */
}Expand description
The amount of time that must pass before the fixed timestep schedule is run again.
Fields
period: DurationDefaults to 1/60th of a second. To configure this value, simply mutate or overwrite this resource.
Implementations
Sourceimpl FixedTime
impl FixedTime
Sourcepub fn new_from_secs(period: f32) -> FixedTime
pub fn new_from_secs(period: f32) -> FixedTime
Creates a new FixedTime struct with a period specified in f32 seconds
Sourcepub fn tick(&mut self, delta_time: Duration)
pub fn tick(&mut self, delta_time: Duration)
Adds the delta_time to the accumulated time so far.
Sourcepub fn accumulated(&self) -> Duration
pub fn accumulated(&self) -> Duration
Returns the current amount of accumulated time
Sourcepub fn expend(&mut self) -> Result<(), FixedUpdateError>
pub fn expend(&mut self) -> Result<(), FixedUpdateError>
Expends one period of accumulated time.
[Err(FixedUpdateError)] will be returned